'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _ajv = require('ajv');

var _ajv2 = _interopRequireDefault(_ajv);

var _validationError = require('./validation-error');

var _validationError2 = _interopRequireDefault(_validationError);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getErrorData(err) {
  switch (err.keyword) {
    case 'required':
      return {
        pointer: `${err.dataPath}/${err.params.missingProperty}`,
        message: err.message
      };
    case 'enum':
      return {
        pointer: `${err.dataPath.replace(/\./g, '/')}`,
        message: `${err.message} [${err.params.allowedValues.join(',')}]`
      };
    case 'type':
      return {
        pointer: `${err.dataPath.replace(/\./g, '/')}`,
        message: err.message
      };
    case 'additionalProperties':
      return {
        pointer: `${err.dataPath}/${err.params.additionalProperty}`,
        message: err.message
      };
    default:
      return {
        message: err.message
      };
  }
}

function getError(err) {
  err = getErrorData(err);
  return new _validationError2.default(err.pointer, err.message);
}

class Validator {
  constructor(schemas) {
    this.ajv = new _ajv2.default({ allErrors: true });
    _lodash2.default.each(schemas, this.ajv.addSchema.bind(this.ajv));
  }

  validate(schema, obj) {
    const valid = this.ajv.validate(schema, obj);
    if (valid) {
      return;
    }

    return _lodash2.default.map(this.ajv.errors, getError);
  }
}
exports.default = Validator;